@@ -10,10 +10,10 @@ use Webqq::Client::Cache;
 use Webqq::Message::Queue;
 
 #定义模块的版本号
-our $VERSION = "7.1";
+our $VERSION = "7.2";
 
 use LWP::UserAgent;#同步HTTP请求客户端
-use AnyEvent::UserAgent;#异步HTTP请求客户端
+use Webqq::UserAgent;#异步HTTP请求客户端
 
 use Webqq::Client::Util qw(console);
 
@@ -123,7 +123,7 @@ sub new {
         ua_retry_times              =>  5, 
         je                          =>  undef,
         last_dispatch_time          =>  undef,
-        send_interval               =>  2,
+        send_interval               =>  3,
         
     };
     $self->{ua} = LWP::UserAgent->new(
@@ -132,7 +132,7 @@ sub new {
                 timeout         =>  300,
                 ssl_opts        =>  {verify_hostname => 0},
     );
-    $self->{asyn_ua} = AnyEvent::UserAgent->new(
+    $self->{asyn_ua} = Webqq::UserAgent->new(
                 cookie_jar  =>  $self->{cookie_jar},
                 agent       =>  $agent,
                 request_timeout =>  300,
@@ -153,6 +153,7 @@ sub new {
         });
     }
     $self->{default_qq_param} =  dclone($self->{qq_param});
+    $self->{default_qq_database} = dclone($self->{qq_database});
     #全局变量，方便其他包引用$self
     $Webqq::Client::_CLIENT = $self;
     return bless $self;
@@ -280,7 +281,6 @@ sub relogin{
     $self->{ua}->cookie_jar($self->{cookie_jar});
     $self->{asyn_ua}->cookie_jar($self->{cookie_jar});
     #重新设置初始化参数
-    $self->{qq_param} = dclone($self->{default_qq_param});
     $self->{cache_for_uin_to_qq} = Webqq::Client::Cache->new;
     $self->{cache_for_group_sig} = Webqq::Client::Cache->new;
     $self->{cache_for_group} = Webqq::Client::Cache->new;
@@ -288,6 +288,8 @@ sub relogin{
     $self->{cache_for_friend} = Webqq::Client::Cache->new;
     $self->{cache_for_stranger} = Webqq::Client::Cache->new;
     $self->{cache_for_single_long_nick} = Webqq::Client::Cache->new;
+    $self->{qq_param} = dclone($self->{default_qq_param});
+    $self->{qq_database} = dclone($self->{default_qq_database});
     $self->login(qq=>$self->{default_qq_param}{qq},pwd=>$self->{default_qq_param}{pwd});
 }
 sub _get_vfwebqq;
@@ -687,7 +689,15 @@ sub update_group_info{
                         last;
                     }
                 }
-                push @{ $self->{qq_database}{group} }, $group_info if $flag == 0;
+                if($flag == 0){
+                    push @{ $self->{qq_database}{group} }, $group_info ;
+                    if(ref $self->{on_new_group} eq 'CODE'){
+                        eval {
+                            $self->{on_new_group}->(dclone($group_info));
+                        };
+                        console $@ . "\n" if $@;
+                    }
+                }
             }
             else{
                 push @{ $self->{qq_database}{group} }, $group_info;
@@ -865,7 +875,7 @@ sub _detect_new_group_member2 {
     return if ref $group_new->{minfo} ne 'ARRAY';
     my %e = map {$_->{uin} => undef} @{$group_old->{minfo}};
     for my $new (@{$group_new->{minfo}}){
-        #旧的有，新的没有，说明是已经退群的成员
+        #旧的没有，新的有，说明是新增群成员
         unless(exists $e{$new->{uin}}){
             if(ref $self->{on_new_group_member} eq 'CODE'){
                 eval{
